# Standard Library

```{warning}
The documentation for the standard library is still a work in progress, it may be
incomplete or outright missing in areas.
```

Torii provides a standard library with various useful components for implementing designs ranging from simple to complex.

```{toctree}
:maxdepth: 2

coding/index
cdc
fifo

soc/index
stdio/index
vendor/index
```
